﻿//
// Copyright (c) 2002-2023 WEINZIERL ENGINEERING GmbH
// All rights reserved.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY,
// WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using kdrive;
using kdrive.express.bindings;

namespace kdrive_express_tunneling_keyring
{
	class Program
	{
		static void Main(string[] args)
		{
			try
			{
				Logger.SetConsoleChannel();
				Logger.SetLevels(Logger.Level.Information);

				// the path to keyring project file and it's password
				String keyringFile = "data/keyring.knxkeys";
				String keyringPassword = "123456";

				// Import the ETS keyring project
				Keyring keyring = new Keyring();
				keyring.ImportKnxKeys(keyringFile, keyringPassword);

				// Trace some keyring project info
				String projectName = String.Format("Project name: {0}", keyring.GetProjectName());
				Logger.Log(Logger.Level.Information, projectName);
				String projectCreator = String.Format("Created by: {0}", keyring.GetProjectCreator());
				Logger.Log(Logger.Level.Information, projectCreator);

				using (AccessPort accessPort = new AccessPort())
				{
					// Use the keyring project for the tunneling port
					// (The password, etc will set automatic from the keyring project)
					accessPort.SetKeyring(keyring);

					// sets security user id (optional; default is 1)
					accessPort.SetTunnelingPortUserId(2);

					// Open a Tunneling connection with a specific IP Interface,
					// you will probably have to change the IP address
					accessPort.OpenIpTunneling("192.168.1.7");

					// ...

					accessPort.Close();
				}
			}
			catch (kdrive.KdriveException exception)
			{
				Console.WriteLine(exception.Message);
			}
			finally
			{
				Logger.Shutdown();
			}
		}

	}
}